@@ -1,13 +1,16 @@
 #ifndef _SUCK_BOTH_H
 #define _SUCK_BOTH_H 1
 
+#include <stdio.h> /* for FILE */
+#include <sys/types.h>
 #include <netdb.h> /* for struct hostent */
 #include "suck_config.h" /* for debug etc stuff */
 
 /* declarations */
-int sgetline(int fd, char **sbuf);
-int sputline(int fd, const char *outbuf);
-int connect_to_nntphost(const char *host, struct hostent **, FILE *, unsigned short int);
+int sgetline(int fd, char **sbuf, int, void *);
+int sputline(int fd, const char *outbuf, int, void *);
+int connect_to_nntphost(const char *host, struct hostent **, FILE *, unsigned short int, int, void **);
+void disconnect_from_nntphost(int, int, void **);
 char *number(char *sp, int *intPtr);
 char *get_long(char *, long *);
 struct hostent *get_hostent(const char *host);
@@ -24,6 +27,8 @@ char *str_int(int);
 char *str_long(long);
 void do_debug(const char *, ...);
 void do_debug_binary(int, const char *);
+const char *null_str(const char *);
+const char *true_str(int);
 
 #define N_DEBUG "debug.suck"
 
