@@ -5,6 +5,7 @@
 /* be used. */
 
 #include <stdio.h>
+
 #include "suck_config.h"
 #include "suck.h"
 #include "both.h"
@@ -20,21 +21,29 @@
 #undef USE_NDBM
 #undef USE_DBZ
 #undef USE_INN2
+#undef USE_INN23
 #endif
 /* else if have GDBM use it */
 #ifdef USE_GDBM
 #undef USE_NDBM
 #undef USE_DBZ
 #undef USE_INN2
+#undef USE_INN23
 #endif
 /* else if have NDBM use it */
 #ifdef USE_NDBM
 #undef USE_DBZ
 #undef USE_INN2
+#undef USE_INN23
 #endif
 /* use DBZ if we have it */
 #ifdef USE_DBZ
 #undef USE_INN2
+#undef USE_INN23
+#endif
+/* use INN2 if we have it */
+#ifdef USE_INN2
+#undef USE_INN23
 #endif
 
 #ifdef USE_DBM
@@ -70,6 +79,19 @@ static DBM *db = NULL;	/* I know this isn't too pretty, but its the easiest way
 #include <dbz.h>
 #define close_history() dbzclose()
 #endif
+#ifdef USE_INN23
+#include <sys/types.h>
+#include <configdata.h>
+#include <libinn.h>
+#include <dbz.h>
+#define close_history() dbzclose()
+#define USE_INN2    /* we need the rest of the inn2 code, only the includes are different */
+#endif
+
+#ifdef DMALLOC
+#include <dmalloc.h>
+#endif
+
 
 /* function prototypes */
 int open_history(const char *);
@@ -152,7 +174,9 @@ int open_history(const char *history_file) {
 #ifdef DO_TAGGED_HASH
 	opt.pag_incore=INCORE_MEM;
 #else
-	opt.idx_incore=INCORE_MEM;  /* per man page speeds things up */
+#ifndef USE_INN23
+	opt.idx_incore=INCORE_MEM;  /* per man page speeds things up, inn-2.3 doesn't need this */
+#endif	
 #endif
 	opt.exists_incore=INCORE_MEM;
 	dbzsetoptions(opt);
