@@ -30,6 +30,10 @@
 #include <regex.h>
 #endif
 
+#ifdef DMALLOC
+#include <dmalloc.h>
+#endif
+
 #include "both.h"
 #include "suck.h"
 #include "suckutils.h"
@@ -165,13 +169,14 @@ PKillStruct parse_killfile(int which, int logfile_yn, int debug, int ignore_post
 			if(debug == TRUE) {
 				do_debug("Pass 1 & 2 kill file: %s\n", full_path(Masterkill->ignore_postfix, FP_DATADIR, filename));
 			}
+	
 			while(fgets(buf, MAXLINLEN, fptr) != NULL && doprg == FALSE) {
+				/* nuke nl, so file names are correct, etc */
+				i = strlen(buf);
+				if(buf[i-1] == '\n') {
+					buf[i-1] = '\0';
+				}
 				if(debug ==  TRUE) {
-				/* so output looks better */
-					i = strlen(buf);
-					if(buf[i-1] == '\n') {
-						buf[i-1] = '\0';
-					}
 					do_debug("Read kill file line: %s\n", buf);
 				}
 				if(strncmp(buf, Params[PARAM_GROUP].name, (size_t) Params[PARAM_GROUP].len) == 0) {
@@ -488,14 +493,14 @@ int get_one_article_kill(PMaster master, int logcount, long itemon) {
 		else {
 			fputs(inbuf, stdout);
 			fputs("\n", stdout);
-			retval = get_chunk_mem(master, &len, CHUNK_BODY, &inbuf);
-			if(retval == RETVAL_OK) {
-				fwrite(inbuf, sizeof(inbuf[0]), len, stdout);
-				/* this is needed as a separator */
-				/* in stdout version */
-				fputs(".\n", stdout);
-			}			
-			
+			if(master->header_only == FALSE) {
+				retval = get_chunk_mem(master, &len, CHUNK_BODY, &inbuf);
+				if(retval == RETVAL_OK) {
+					fwrite(inbuf, sizeof(inbuf[0]), len, stdout);
+				}
+			}
+                        /* this is needed as a separator in stdout version */
+			fputs(".\n", stdout);
 		}
 		if(retval == RETVAL_OK) {
 			master->nrgot++;
@@ -560,7 +565,7 @@ int get_chunk_mem(PMaster master, unsigned long *size, int which, char **retbuf)
 		}
 	}
 	while(buf != NULL && done == FALSE) {
-		len=sgetline(master->sockfd, &inbuf);
+		len=sgetline(master->sockfd, &inbuf, master->do_ssl, master->ssl_struct);
 		(void) TimerFunc(TIMER_ADDBYTES, len, NULL);
 		if(len < 0) {
 			free(buf);
