@@ -14,18 +14,31 @@ package Embed::Persistant;
 sub perl_rpost {
 
 	my $infile = $_[0];  # input file name
-	my $outfile = "/tmp/tmp_rpost";
+	my $outfile = "/tmp/tmp.rpost";
 
 	# open files for input and output
-	open IFP, "<${infile}" or die "Can't read ${infile}";
+
+	# if we can't open the file, fail with the filename
+	# rpost will then handle the error
+	# We do this since rpost can't differentiate between
+	# a missing file or a script file
+	open IFP, "<${infile}" or return $infile;
+#	open IFP, "<${infile}" or die "Can't read ${infile}";
 	open OFP, ">${outfile}" or die "Can't create ${outfile}";
 
 	# now strip out what we don't need
 	while ( $line = <IFP>) {
-	    if($line !~ /^NNTP-Posting|^Xref/) {
+	    if($line !~ /^NNTP-Posting|^Xref|^X-Trace|^X-Comp/) {
 		# write out to file
 		print OFP $line;
 	    }
+	    if($line =~ /^$/) {
+		last;	# end of header don't need to test anymore
+		# this test is here so the line gets printed out.
+	    }
+	}
+	while ( $line = <IFP> ) {
+		print OFP $line;
 	}
 
 	close IFP;
