@@ -26,14 +26,18 @@
 #include <limits.h>
 #endif
 
-#include <netdb.h>
 #include <string.h>
 #include <sys/types.h>
+#include <netdb.h>
 #include <sys/stat.h>
 #include <math.h>
 #include <errno.h>
 #include <ctype.h>
 
+#ifdef DMALLOC
+#include <dmalloc.h>
+#endif
+
 #include "suck_config.h"
 #include "both.h"
 #include "suck.h"
@@ -69,6 +73,7 @@ int parse_args(PMaster, int, char *[]);
 int get_group_number(PMaster, char *);
 int do_supplemental(PMaster);
 int do_sup_bynr(PMaster, char *);
+int do_nodownload(PMaster);
 #ifdef MYSIGNAL
 RETSIGTYPE sighandler(int);
 void pause_signal(int, PMaster);
@@ -96,6 +101,7 @@ char **batch_phrases=default_batch_phrases;
 char **xover_phrases=default_xover_phrases;
 char **xover_reasons=default_xover_reasons;
 
+
 enum { STATUS_STDOUT, STATUS_STDERR };
 enum { RESTART_YES, RESTART_NO, RESTART_ERROR };
 
@@ -108,8 +114,9 @@ enum {
 	ARG_KLOG_LONG, ARG_MODEREADER, ARG_PORTNR, ARG_PASSWD, ARG_RESCAN, ARG_STATLOG, \
 	ARG_USERID, ARG_VERSION, ARG_WAIT, ARG_LOCALHOST, ARG_TIMEOUT, ARG_NRMODE, ARG_AUTOAUTH, \
 	ARG_NODEDUPE, ARG_NO_CHK_MSGID, ARG_READACTIVE, ARG_PREBATCH, ARG_SKIP_ON_RESTART, \
-	ARG_KLOG_NAME, ARG_USEGUI, ARG_XOVER, ARG_CONN_DEDUPE, ARG_POST_FILTER, ARG_CONN_ACTIVE,
-	ARG_HIST_FILE, ARG_HEADER_ONLY, ARG_ACTIVE_LASTREAD, ARG_USEXOVER,
+	ARG_KLOG_NAME, ARG_USEGUI, ARG_XOVER, ARG_CONN_DEDUPE, ARG_POST_FILTER, ARG_CONN_ACTIVE, \
+	ARG_HIST_FILE, ARG_HEADER_ONLY, ARG_ACTIVE_LASTREAD, ARG_USEXOVER, ARG_RESETCOUNTER, \
+	ARG_LOW_READ, ARG_SHOW_GROUP, ARG_USE_SSL, ARG_LOCAL_SSL, ARG_BATCH_POST_NR, 
 }; 
 
 typedef struct Arglist{
@@ -127,6 +134,7 @@ const Args arglist[] = {
 	{"bl", "batch_lmove",  1, ARG_BATCH_LMOVE, 40},
 	{"bf", "batch_innfeed",1, ARG_BATCH_INNFEED, 40},
 	{"bp", "batch_post",   0, ARG_BATCH_POST, -1},
+	{"bP", "batch_post_nr", 1, ARG_BATCH_POST_NR, 72},	
 	{"c",  "cleanup",      0, ARG_CLEANUP, -1},
 	{"dt", "dir_temp",    1, ARG_DIR_TEMP, 37},
 	{"dd", "dir_data",    1, ARG_DIR_DATA, 37},
@@ -139,12 +147,18 @@ const Args arglist[] = {
 	{"i",  "default_activeread", 1, ARG_ACTIVE_LASTREAD, 65},	
 	{"k",  "kill_no_postfix", 0, ARG_NO_POSTFIX, -1},
 	{"l",  "language_file", 1, ARG_LANGUAGE, 47},
+	{"lr", "low_read", 0, ARG_LOW_READ, -1},	
 	{"m",  "multifile", 0, ARG_MULTIFILE, -1},
 	{"n",  "number_mode", 0, ARG_NRMODE, -1},
 	{"p",  "postfix", 1, ARG_POSTFIX, 36},
 	{"q",  "quiet", 0, ARG_QUIET, -1},
 	{"r",  "rnews_size", 1, ARG_RNEWSSIZE, 35},
+	{"rc", "reset_counter", 0, ARG_RESETCOUNTER, -1},	
 	{"s",  "def_status_log", 0, ARG_DEF_STATLOG, -1},
+	{"sg", "show_group", 0, ARG_SHOW_GROUP, -1},
+#ifdef HAVE_LIBSSL
+	{"ssl","use_ssl", 0, ARG_USE_SSL, -1},
+#endif
 	{"u",  "auto_authorization", 0, ARG_AUTOAUTH, -1},
 	{"w",  "wait_signal", 2, ARG_WAIT_SIG, 46},
 	{"x",  "no_chk_msgid", 0, ARG_NO_CHK_MSGID, -1},
@@ -171,6 +185,9 @@ const Args arglist[] = {
 	{"P",  "password", 1, ARG_PASSWD, 44},
 	{"R",  "no_rescan", 0, ARG_RESCAN, -1},
 	{"S",  "status_log", 1, ARG_STATLOG, 42},
+#ifdef HAVE_LIBSSL
+	{"SSL" "local_use_ssl", 0, ARG_LOCAL_SSL, -1},
+#endif
 #ifdef TIMEOUT
 	{"T",  "timeout", 1, ARG_TIMEOUT, 52},
 #endif	
@@ -199,7 +216,12 @@ int main(int argc, char *argv[]) {
 #ifdef LOCKFILE
 	const char *lockfile = NULL;
 #endif
-
+#ifdef MYSIGNAL
+#ifdef HAVE_SIGACTION
+	struct sigaction sigs;
+#endif
+#endif	
+	
 	/* initialize master structure */
 	master.head = master.curr = NULL;
 	master.nritems = master.nrgot = 0;
@@ -257,6 +279,14 @@ int main(int argc, char *argv[]) {
 	master.active_lastread = ACTIVE_DEFAULT_LASTREAD;
 	master.use_xover = FALSE;
 	master.xoverview = NULL;
+	master.resetcounter = FALSE;
+	master.low_read = FALSE;
+	master.show_group = FALSE;
+	master.do_ssl = FALSE;
+	master.ssl_struct = NULL;
+	master.local_ssl = FALSE;
+	master.local_ssl_struct = NULL;
+	master.batch_post_nr = 0;
 	
 	/* have to do this next so if set on cmd line, overrides this */
 
@@ -355,7 +385,9 @@ int main(int argc, char *argv[]) {
 		do_debug("master.header_only = %s\n", true_str(master.header_only));
 		do_debug("master.active_lastread = %d\n", master.active_lastread);
 		do_debug("master.use_xover = %s\n", true_str(master.use_xover));
-		
+		do_debug("master.do_ssl = %s\n", true_str(master.do_ssl));
+		do_debug("master.local_ssl = %s\n", true_str(master.local_ssl));
+		do_debug("master.batch_post_nr =  %d\n",master.batch_post_nr);
 #ifdef TIMEOUT
 		do_debug("TimeOut = %d\n", TimeOut);
 #endif
@@ -384,10 +416,24 @@ int main(int argc, char *argv[]) {
 #endif
 
 #ifdef MYSIGNAL
-		signal(MYSIGNAL, sighandler); 	/* set up signal handlers */
-		signal(PAUSESIGNAL, sighandler);
-		signal_block(MYSIGNAL_SETUP);	/* set up sgetline() to block signal */ 
-		pause_signal(PAUSE_SETUP, &master);	/* set up routine for pause swap if signal */	
+		/* set up signal handlers */
+#ifdef HAVE_SIGACTION
+		sigemptyset(&(sigs.sa_mask));
+		sigs.sa_handler = sighandler;
+		sigs.sa_flags = 0;
+		if(sigaction(MYSIGNAL, &sigs, NULL) == -1 || sigaction(PAUSESIGNAL, &sigs, NULL) == -1) {
+			MyPerror(suck_phrases[67]);
+		}
+		else {
+			signal_block(MYSIGNAL_SETUP);	/* set up sgetline() to block signal */ 
+			pause_signal(PAUSE_SETUP, &master);	/* set up routine for pause swap if signal */
+		}
+#else
+		/* the old-fashioned way */
+		signal(MYSIGNAL, sighandler);
+		signal(PAUSESIGNAL, sighander);
+		pause_signal(PAUSE_SETUP, &master);
+#endif	
 #endif
 		load_phrases(&master);	/* this has to be here so rest prints okay */
 
@@ -469,6 +515,9 @@ int main(int argc, char *argv[]) {
 				if(retval == RETVAL_OK) {
 					retval = do_supplemental(&master);
 				}
+				if(retval == RETVAL_OK) {
+                                        retval = do_nodownload(&master);
+                                }
 				if(retval == RETVAL_OK && master.head != NULL && master.nritems > 0) {
 					/* if we don't have any messages, we don't need to do this */
 					if(master.no_dedupe == FALSE) {
@@ -501,12 +550,12 @@ int main(int argc, char *argv[]) {
 				
 			}
 			/* send quit, and get reply */
-			sputline(master.sockfd,"quit\r\n");
+			sputline(master.sockfd,"quit\r\n", master.do_ssl, master.ssl_struct);
 			if(master.debug == TRUE) {
 				do_debug("Sending command: quit\n");
 			}
 			do {
-				resp = sgetline(master.sockfd, &inbuf);
+				resp = sgetline(master.sockfd, &inbuf, master.do_ssl, master.ssl_struct);
 				if(resp>0) {
 					if(master.debug == TRUE) {
 						do_debug("Quitting GOT: %s", inbuf);
@@ -517,7 +566,7 @@ int main(int argc, char *argv[]) {
 			}while(nr != 205 && resp > 0);	
 		}
 		if(master.sockfd >= 0) {
-			close(master.sockfd);
+			disconnect_from_nntphost(master.sockfd, master.do_ssl, &master.ssl_struct);
 			print_phrases(master.msgs,suck_phrases[4], master.host, NULL);
 		}
 		if(master.debug == TRUE) {
@@ -597,21 +646,6 @@ int main(int argc, char *argv[]) {
 	free_phrases();	/* do this last so everything is displayed correctly */
 	exit(retval);
 }
-/*-----------------------------------------------------------*/
-/* print NULL or the string */
-const char *null_str(const char *ptr) {
-	const char *nullp = "NULL";
-
-	return (ptr == NULL) ? nullp : ptr;
-}
-/*-----------------------------------------------------------*/
-/* print TRUE or FALSE if our nr is 0 or non-zero */
-const char *true_str(int nr) {
-	const char *true_s = "TRUE";
-	const char *false_s = "FALSE";
-	
-	return (nr == TRUE) ? true_s : false_s;
-}
 /*------------------------------------------------------------*/
 int do_connect(PMaster master, int which_time) {
 
@@ -623,9 +657,9 @@ int do_connect(PMaster master, int which_time) {
 	
 	if(which_time != CONNECT_FIRST) {
 		/* close down previous connection */
-		sputline(master->sockfd, "quit\r\n");
+		sputline(master->sockfd, "quit\r\n", master->do_ssl, master->ssl_struct);
 		do {
-			resp = sgetline(master->sockfd, &inbuf);
+			resp = sgetline(master->sockfd, &inbuf, master->do_ssl, master->ssl_struct);
 			if(resp>0) {
 				if(master->debug == TRUE) {
 					do_debug("Reconnect GOT: %s", inbuf);
@@ -633,8 +667,8 @@ int do_connect(PMaster master, int which_time) {
 				number(inbuf, &nr);
 			}
 			
-		}while(nr != 205 && resp > 0);		
-		close(master->sockfd);
+		}while(nr != 205 && resp > 0);
+		disconnect_from_nntphost(master->sockfd, master->do_ssl, &master->ssl_struct);
 
 		/* now reset everything */
 		if(master->curr != NULL) {
@@ -647,11 +681,13 @@ int do_connect(PMaster master, int which_time) {
 		do_debug("Connecting to %s on port %d\n", master->host, master->portnr);
 	}
 	fp = (which_time == CONNECT_FIRST) ? master->msgs : NULL;
-	master->sockfd = connect_to_nntphost( master->host, &hi, fp , master->portnr);
+
+	master->sockfd = connect_to_nntphost( master->host, &hi, fp, master->portnr, master->do_ssl, &master->ssl_struct);
+	
 	if(master->sockfd < 0 ) {
 		retval = RETVAL_ERROR;
 	}
-	else if(sgetline(master->sockfd, &inbuf) < 0) {
+	else if(sgetline(master->sockfd, &inbuf, master->do_ssl, master->ssl_struct) < 0) {
 	 	/* Get the announcement line */
 		retval = RETVAL_ERROR;
 	}
@@ -804,7 +840,14 @@ int do_one_group(PMaster master, char *buf, char *group, FILE *newrc, long lastr
 			/* the > 0 is needed, since if a nnrp site has no article it will reset */
 			/* the count to 0.  So not an error */
   			if(lastread > high && high > 0) {
-  				print_phrases(master->msgs,suck_phrases[13],group,str_int(high),NULL);
+				if(master->resetcounter == TRUE) {
+					/* reset lastread to low, so we pick up all articles in the group */
+					lastread = low;
+					print_phrases(master->msgs,suck_phrases[71],group,str_int(high),str_int(low),NULL);
+				}
+				else {
+					print_phrases(master->msgs,suck_phrases[13],group,str_int(high),NULL);
+				}
   			}
 
 			if(lastread < 0 ) {
@@ -828,7 +871,14 @@ int do_one_group(PMaster master, char *buf, char *group, FILE *newrc, long lastr
 				}
 				/* now set the max nr of messages to read */
 				if(maxread > 0 && high-maxread > lastread) {
-					lastread = high-maxread;
+					if(master->low_read == TRUE) {
+						/* instead of limiting from the high-water mark (the latest articles) */
+						/* limit from the low-water mark (the oldest articles) */
+						high = (lastread+1) + maxread;
+					}
+					else {
+						lastread = high-maxread;
+					}
 					print_phrases(master->msgs, suck_phrases[14], group, str_int(maxread), NULL);
 				}
 				print_phrases(master->msgs, suck_phrases[15], group, str_long(high-lastread), str_long(lastread+1), str_long(high), NULL);
@@ -849,7 +899,7 @@ int do_one_group(PMaster master, char *buf, char *group, FILE *newrc, long lastr
 					}
 					else {
 						do {
-							if(sgetline(master->sockfd, &inbuf) < 0) {
+							if(sgetline(master->sockfd, &inbuf, master->do_ssl, master->ssl_struct) < 0) {
 								retval = RETVAL_ERROR;
 							}
 							else if (*inbuf != '.' ) {
@@ -870,8 +920,11 @@ int do_one_group(PMaster master, char *buf, char *group, FILE *newrc, long lastr
 /*-----------------------------------------------------------*/
 int get_articles(PMaster master) {
 
-	int retval, logcount, i;
+	int retval, logcount, i, grpnr, grplen;
 	long loop, downloaded;
+	PGroups grps;
+	const char *grpname;
+	const char *empty = "";
 	
 #ifdef HAVE_GETTIMEOFDAY
 	double bps;
@@ -880,7 +933,11 @@ int get_articles(PMaster master) {
 #ifdef KILLFILE
 	int ( *get_message)(PMaster, int, long); /* which function will we use get_one_article or get_one_article_kill) */
 
-	/* do we use killfiles? */
+	grpnr = -1;
+	grps = NULL;
+	grpname = empty;
+	grplen = 0;
+		/* do we use killfiles? */
 	get_message = (master->killp == NULL) ? get_one_article : get_one_article_kill;
 #endif
 	retval = RETVAL_OK;
@@ -951,10 +1008,36 @@ int get_articles(PMaster master) {
 #endif /* HAVE_GETTIMEOFDAY */
 						}
 						else {
+							if(master->show_group == TRUE) {
+							/* add the group name (if available) to the line printed */
+								if((master->curr)->groupnr >= 0) {
+									if((master->curr)->groupnr != grpnr) {
+										grpname = empty;
+										grpnr = (master->curr)->groupnr;
+										/* new group name find it */
+										grps = master->groups;
+										while(grps != NULL && grps->nr != grpnr) {
+											grps = grps->next;
+										}
+										if(grps != NULL) {
+											grpname = grps->group;
+											/* calculate max len for format of printf*/
+											/* which erases the previous group name */
+											if(strlen(grpname) > grplen) {
+												grplen = strlen(grpname);
+											}
+										}
+									}		
+								}
+								else {
+									grpnr = -1;
+									grpname = empty;
+								}
+							}
 #ifndef HAVE_GETTIMEOFDAY
-							fprintf(master->msgs, "%5ld\r",master->nritems  - loop);
+							fprintf(master->msgs, "%5ld %-*s\r",master->nritems  - loop, grplen, grpname);
 #else
-							fprintf(master->msgs, "%5ld %9.1f %s\r",master->nritems-loop,bps,suck_phrases[5]);
+							fprintf(master->msgs, "%5ld %9.1f %s %-*s\r",master->nritems-loop,bps,suck_phrases[5], grplen, grpname);
 #endif /* HAVE_GETTIMEOFDAY */
 						}
 						fflush(master->msgs);	/* so message gets printed now */
@@ -979,8 +1062,21 @@ int get_articles(PMaster master) {
 					if(master->curr != NULL) {
 						(master->curr)->sentcmd = FALSE;	/* if we sent command force resend */
 					}
-				} 
-
+				}
+				// do a local post every x number of articles
+				if(master->batch == BATCH_LIHAVE && master->batch_post_nr > 0 && master->nrgot >=  master->batch_post_nr) {
+					fclose(master->innfeed);
+					master->innfeed = NULL;
+					do_post_filter(master);
+					retval = do_localpost(master);
+					if(retval == RETVAL_OK) {
+						master->nrgot = 0; // so if no more articles left we don't try to post in main routine
+						if((master->innfeed = fopen(full_path(FP_GET, FP_TMPDIR, master->batchfile), "a")) == NULL) {
+							MyPerror(full_path(FP_GET, FP_TMPDIR, master->batchfile));
+							retval = RETVAL_ERROR;
+						}
+					}
+				}
  
 		 	} /* end while */
 			db_close(master);
@@ -1061,7 +1157,7 @@ int do_supplemental(PMaster master) {
 				 /* now have to get message-id and the . */
 				 done = FALSE;
 				 while( done == FALSE) {
-					 if(sgetline(master->sockfd, &resp) < 0) {
+					 if(sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct) < 0) {
 						 retval = RETVAL_ERROR;
 						 done = TRUE;
 					 }
@@ -1083,7 +1179,69 @@ int do_supplemental(PMaster master) {
 	 
 	 return retval;
 	 
- } 
+ }
+ /*---------------------------------------------------------------------*/
+ int do_nodownload(PMaster master) {
+	 int i, retval = RETVAL_OK;
+	 FILE *fp;
+	 PList item, prev;
+	 char linein[MAXLINLEN+1];
+	 long nrlines = 0, nrnuked = 0;
+	 
+	 if((fp = fopen(full_path(FP_GET, FP_DATADIR, N_NODOWNLOAD), "r")) != NULL) {
+		print_phrases(master->msgs, suck_phrases[68], NULL);
+		while(retval == RETVAL_OK && fgets(linein, MAXLINLEN, fp) != NULL) {
+			nrlines++;
+			i = strlen(linein) - 1; /* so it points at last char */
+			/* strip off nl */
+			if(linein[i] == '\n') {
+				linein[i] = '\0';
+				i--;
+			}
+			/* strip off extra spaces on the end */
+			while(isspace(linein[i])){
+				linein[i] = '\0';
+				i--;
+			}
+			item = master->head;
+			prev = NULL;
+			/* find start of msgid */
+			if(linein[0] != '<') {
+				error_log(ERRLOG_REPORT, suck_phrases[69], linein, NULL);
+			}
+			else {
+				if(master->debug == TRUE) {
+					do_debug("Checking Nodownload - %s\n", linein);
+				}
+				
+				while((item != NULL) && (cmp_msgid(linein, item->msgnr) == FALSE)) {
+					prev = item;
+					item = item->next;
+				}
+				if(item != NULL) {
+					/* found a match, remove from the list */
+					if(master->debug == TRUE) {
+						do_debug("Matched, nuking from list\n");
+					}
+					nrnuked++;
+					master->nritems--;
+					if(item == master->head) {
+						/* change top of list */
+						master->head = (master->head)->next;
+					}
+					else {
+                                                 /* its not the end of the list */
+						prev->next = item->next;
+						free_one_node(item);
+					}
+				}
+			}
+		}
+		fclose(fp);
+		print_phrases(master->msgs, suck_phrases[70], str_long(nrlines), str_long(nrnuked), str_long(master->nritems), NULL);
+	}
+	return retval;
+ }
 /*----------------------------------------------------------------------*/
  int get_group_number(PMaster master, char *grpname) {
 
@@ -1102,7 +1260,7 @@ int do_supplemental(PMaster master) {
 		 }
 	 }
 	 
-	 if(groupnr == 0) {	
+	 if(groupnr == 0) {
 		 /* add group to group list and get group nr */
 		 if((grps = malloc(sizeof(Groups))) == NULL) {
 				/* out of memory */
@@ -1194,7 +1352,6 @@ int allocnode(PMaster master, char *linein, int mandatory, char *group, long msg
 			else if(strlen(st_ptr) >= MAX_MSGID_LEN) {
 				error_log(ERRLOG_REPORT, suck_phrases[63], NULL);
 				free(ptr);
-				retval = RETVAL_ERROR;
 			}
 			else {
 				strcpy(ptr->msgnr, st_ptr);
@@ -1316,11 +1473,13 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 		if(master->debug == TRUE) {
 			do_debug("Sending command: \"%s\"",cmd);
 		}
-		sputline(master->sockfd, cmd);
+		sputline(master->sockfd, cmd, master->do_ssl, master->ssl_struct);
 		(master->curr)->sentcmd = TRUE;
 	}
 	plist = (master->curr)->next;
-	if(plist != NULL) {
+	if(plist != NULL && master->batch_post_nr == 0) {
+		/* if batch_post_nr > 0 we're doing periodic batch posts */
+		/* which confuses the remote server so we can't use pipelining */
 		if(master->nrmode == FALSE || plist->groupnr == (master->curr)->groupnr) {
 		/* can't use pipelining if nrmode on, cause of GROUP command I'll have to send*/
 			if(plist->sentcmd == FALSE) {
@@ -1331,7 +1490,7 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 				if(master->debug == TRUE) {
 					do_debug("Sending command: \"%s\"",cmd);
 				}
-				sputline(master->sockfd, cmd);
+				sputline(master->sockfd, cmd, master->do_ssl, master->ssl_struct);
 				plist->sentcmd = TRUE;
 			}
 		}
@@ -1358,7 +1517,7 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 	}
 
 	/* okay hopefully by this time the remote end is ready */
-	if((len = sgetline(master->sockfd, &resp)) < 0) {
+	if((len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct)) < 0) {
 		retval = RETVAL_ERROR;
 	}
 	else {
@@ -1378,8 +1537,8 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 				if(master->debug == TRUE) {
 					do_debug("Sending command: \"%s\"",cmd);
 				}
-				sputline(master->sockfd, cmd);
-				len = sgetline(master->sockfd, &resp);
+				sputline(master->sockfd, cmd, master->do_ssl, master->ssl_struct);
+				len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);
 				if(master->debug == TRUE) {
 					do_debug("got answer: %s", resp);
 				}
@@ -1393,7 +1552,7 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 		/* 221 = header 220 = article */
 		if(nr == 220 || nr == 221 ) {
 			/* get the article */
-			if((retval = get_a_chunk(master->sockfd, fptr)) == RETVAL_OK) {
+			if((retval = get_a_chunk(master, fptr)) == RETVAL_OK) {
 				master->nrgot++;
 				if (fptr == stdout) {
 					/* gracefully end the message in stdout version */
@@ -1428,7 +1587,7 @@ int get_one_article(PMaster master, int logcount, long itemon) {
 	return retval;
 }
 /*---------------------------------------------------------------------------*/
-int get_a_chunk(int sockfd, FILE *fptr) {
+int get_a_chunk(PMaster master, FILE *fptr) {
 
 	int done, partial, len, retval;
 	char *inbuf;
@@ -1437,13 +1596,13 @@ int get_a_chunk(int sockfd, FILE *fptr) {
 	retval = RETVAL_OK;
 	done = FALSE;
 	partial = FALSE;
-
+	len = 0; /* just to get rid of a compiler warning */
 	/* partial = was the previous line a complete line or not */
 	/* this is needed to avoid a scenario where the line is MAXLINLEN+1 */
 	/* long and the last character is a ., which would make us think */
 	/* that we are at the end of the article when we actually aren't */
 	
-	while(done == FALSE && (len = sgetline(sockfd, &inbuf)) >= 0) {
+	while(done == FALSE && (len = sgetline(master->sockfd, &inbuf, master->do_ssl, master->ssl_struct)) >= 0) {
 
 		TimerFunc(TIMER_ADDBYTES, len, NULL);
 			
@@ -1522,8 +1681,8 @@ RETSIGTYPE sighandler(int what) {
 	  case PAUSESIGNAL:
 		pause_signal(PAUSE_DO, NULL);
 		/* if we don't do this, the next time called, we'll abort */
-		signal(PAUSESIGNAL, sighandler);
-		signal_block(MYSIGNAL_SETUP);	/* jus to be on the safe side */ 
+/*		signal(PAUSESIGNAL, sighandler); */
+/*		signal_block(MYSIGNAL_SETUP); */	/* just to be on the safe side */ 
 		break;
 	  case MYSIGNAL:
 	  default:
@@ -1568,8 +1727,8 @@ void pause_signal(int action, PMaster master) {
 	 if(master->debug == TRUE) {
 		 do_debug("sending command: %s", cmd);
 	 }
-	 sputline(master->sockfd, cmd);
-	 len = sgetline(master->sockfd, &resp);	
+	 sputline(master->sockfd, cmd, master->do_ssl, master->ssl_struct);
+	 len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);	
 	 if( len < 0) {	
 		 retval = RETVAL_ERROR;		  	
 	 }					
@@ -1586,11 +1745,11 @@ void pause_signal(int action, PMaster master) {
 			 retval = do_authenticate(master);
 			 if(retval == RETVAL_OK) {
 				 /* resend command */
-				 sputline(master->sockfd, cmd);
+				 sputline(master->sockfd, cmd, master->do_ssl, master->ssl_struct);
 				 if(master->debug == TRUE) {
 					 do_debug("sending command: %s", cmd);
 				 }
-				 len = sgetline(master->sockfd, &resp);
+				 len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);
 				 if( len < 0) {	
 					 retval = RETVAL_ERROR;		  	
 				 }
@@ -1764,6 +1923,9 @@ int parse_args(PMaster master, int arg, char *argv[]) {
 		master->MultiFile = TRUE;
 		master->batchfile = argv[0];
 		break;
+	case ARG_BATCH_POST_NR:
+		master->batch_post_nr = atoi(argv[0]);
+		/* no break fall thru to the rest of batch_post*/
 	case ARG_BATCH_POST:
 		master->batch = BATCH_LIHAVE;
 		master->MultiFile = TRUE;
@@ -1926,11 +2088,30 @@ int parse_args(PMaster master, int arg, char *argv[]) {
 	case ARG_USEXOVER:
 		master->use_xover = TRUE;
 		break;
+	case ARG_RESETCOUNTER:
+		master->resetcounter = TRUE;
+		break;
+	case ARG_LOW_READ:
+		master->low_read = TRUE;
+		break;
+	case ARG_SHOW_GROUP:
+		master->show_group = TRUE;
+		break;
 #ifdef TIMEOUT
 	case ARG_TIMEOUT:
 		TimeOut = atoi(argv[0]);
 		break;
 #endif
+#ifdef HAVE_LIBSSL
+	case ARG_USE_SSL:
+		master->do_ssl = TRUE;
+		master->portnr = DEFAULT_SSL_PORT;
+		break;
+	case ARG_LOCAL_SSL:
+		master->local_ssl = TRUE;
+		break;
+#endif
+			
 	}
 	
 	return retval;
@@ -1948,8 +2129,8 @@ int do_authenticate(PMaster master) {
 	 if(master->debug == TRUE) {
 		 do_debug("sending command: %s", buf);
 	 }
-	 sputline(master->sockfd, buf);
-	 len = sgetline(master->sockfd, &resp);
+	 sputline(master->sockfd, buf, master->do_ssl, master->ssl_struct);
+	 len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);
 	 if( len < 0) {	
 	   retval = RETVAL_ERROR;		  	
 	 }					
@@ -1966,7 +2147,7 @@ int do_authenticate(PMaster master) {
 			 /* we get the second need auth */
 			 /* just ignore it and get the next line */
 			 /* which should be the 381 we need */
-			 len = sgetline(master->sockfd, &resp);
+			 len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);
 			 TimerFunc(TIMER_ADDBYTES, len, NULL);
 			 
 			 number(resp, &nr);
@@ -1978,11 +2159,11 @@ int do_authenticate(PMaster master) {
 		 }
 		 else {
 			 sprintf(buf, "AUTHINFO PASS %s\r\n", master->passwd);
-			 sputline(master->sockfd, buf);
+			 sputline(master->sockfd, buf, master->do_ssl, master->ssl_struct);
 			 if(master->debug == TRUE) {
 				 do_debug("sending command: %s", buf);
 			 }
-			 len = sgetline(master->sockfd, &resp);
+			 len = sgetline(master->sockfd, &resp, master->do_ssl, master->ssl_struct);
 			 if(len < 0) {	
 				 retval = RETVAL_ERROR;		  	
 			 }					
@@ -2114,6 +2295,8 @@ void free_phrases(void) {
 		if(xover_reasons != default_xover_reasons) {
 			free_array(NR_XOVER_REASONS, xover_reasons);
 		}
+
+		
 		
 }
 
