@@ -4,7 +4,7 @@
 #include <stdio.h>	/* for FILE */
 #include "suck_config.h"
 
-/* link list structure one for each article */
+/* Link list structure one for each article */
 typedef struct LinkList {
 	struct LinkList *next;
 	char msgnr[MAX_MSGID_LEN];
@@ -72,6 +72,9 @@ typedef struct {
 	int header_only;
 	int active_lastread;
 	int use_xover;
+	int resetcounter;
+	int low_read;
+	int show_group;
 	unsigned short int portnr;
 	long rnews_size;
 	FILE *msgs;
@@ -94,19 +97,26 @@ typedef struct {
 	void *killp;
 	void *xoverp;
 	POverview xoverview;
+	int do_ssl;
+	void *ssl_struct;
+	int local_ssl;
+	void *local_ssl_struct;
+	int batch_post_nr;
 } Master, *PMaster;
 
-int get_a_chunk(int, FILE *);
+int get_a_chunk(PMaster, FILE *);
 void free_one_node(PList);
 int send_command(PMaster, const char *, char **, int);
 int get_message_index(PMaster);
 int do_one_group(PMaster, char *, char *, FILE *, long, int);
 const char *build_command(PMaster, const char *, PList);
-const char *null_str(const char *);
-const char *true_str(int);
+
 int allocnode(PMaster, char *, int, char *, long);
 int do_connect(PMaster, int);
 
+#ifdef MYSIGNAL
+#endif
+
 enum { RETVAL_ERROR = -1, RETVAL_OK = 0, RETVAL_NOARTICLES, RETVAL_UNEXPECTEDANS, RETVAL_VERNR, \
        RETVAL_NOAUTH, RETVAL_EMPTYKILL, RETVAL_NOXOVER };
 enum { BATCH_FALSE, BATCH_INNXMIT, BATCH_RNEWS, BATCH_LMOVE, BATCH_INNFEED, BATCH_LIHAVE };		/* poss values for batch variable */
