@@ -3,6 +3,8 @@
 
 #define DEFAULT_NNRP_PORT 119 	/* port to talk to on remote machine */
 #define LOCAL_PORT 119		/* port to talk to on local host */
+#define DEFAULT_SSL_PORT 563    /* if using SSL, this is the default port */
+#define LOCAL_SSL_PORT 563       /* if using SSL, for local host */
 
 /* Max length of a Message-ID that is possbile */
 #define MAX_MSGID_LEN 196
@@ -80,6 +82,7 @@
 
 /* String used in RPOST to search for Duplicate Message-ID responses from server */
 #define RPOST_DUPE_STR "Duplicate"
+#define RPOST_DUPE_STR2 "Already got"     /* used by DNews */
 
 /*  FILE NAMES */
 /* Data files read in */
@@ -90,7 +93,7 @@
 #define N_ACTIVE_IGNORE "active-ignore"         /* list of newsgroups ignored by read local active option */
 #define N_LMOVE_CONFIG  "lmove-config"          /* config file for lmove */
 #define N_XOVER         "suckxover"             /* parameter file for which articles NOT to download via xover */
-
+#define N_NODOWNLOAD    "sucknodownload"        /* file name for message-ids that I never download */
 #define N_PHRASES "/usr/local/lib/suck.phrases"	/* default location for phrase file */
 #define HISTORY_FILE "/usr/news/db/history"     /* default location for history file */
 
