@@ -11,7 +11,8 @@ const char *default_chkh_phrases[] = {
 	"Bogus line, ignoring: %v1%",
 	"Processed history, %v1% dupes removed\n",
 	"Out of Memory, skipping history check",
-	"Processing History Database "			/* 5 */
+	"Processing History Database ",			/* 5 */
+	"Unknown error reading history file %v1%\n",
 };
 
 const char *default_dedupe_phrases[] = {
@@ -152,6 +153,14 @@ const char *default_suck_phrases[] = {
 	"No post filter provided\n",
 	"----Message-ID too long----\nincrease MAX_MSGID_LEN in suck_config.h, recompile, and re-run.\n",
 	"No history file path provided\n",
+	"No default read for new active groups provided\n", /* 65 */
+	"Invalid default read for new active group, must be <= 0\n",
+	"Error setting up signal handlers",
+	"Processing Nodownload File\n",
+        "Invalid line in Nodownload File %v1%, ignoring\n",
+        "Nodownload File processed, %v1% lines read, %v2% articles deleted, %v3% articles remaining\n", /* 70 */
+	"%v1% - %v2%... High Number article is low, resetting last read to %v3%\n",
+	"No batch_post count provide\n",
 };
 
 const char *default_batch_phrases[] = {
@@ -212,6 +221,8 @@ const char *default_xover_reasons[] = {
 	"Xover - No Match on Group Keep file", /* 5 */
 	"Xover - Multiple Matches/Tiebreaker used",
 	"Xover - Too many Groups in Xref",
+	"Xover - Match by external program",
+	"Xover - Match by perl program"
 };
 
 int nr_suck_phrases= sizeof(default_suck_phrases)/sizeof(default_suck_phrases[0]);
@@ -226,3 +237,4 @@ int nr_active_phrases=sizeof(default_active_phrases)/sizeof(default_active_phras
 int nr_batch_phrases=sizeof(default_batch_phrases)/sizeof(default_batch_phrases[0]);
 int nr_xover_phrases=sizeof(default_xover_phrases)/sizeof(default_xover_phrases[0]);
 int nr_xover_reasons=sizeof(default_xover_reasons)/sizeof(default_xover_reasons[0]);
+
